@@ -41,7 +41,7 @@ class QModelIndex;
 class KITEMVIEWS_EXPORT KListWidgetSearchLine : public QLineEdit
 {
     Q_OBJECT
-#ifndef KITEMVIEWS_NO_DEPRECATED
+#if KITEMVIEWS_BUILD_DEPRECATED_SINCE(5, 0)
     Q_PROPERTY(QString clickMessage READ clickMessage WRITE setClickMessage)
 #endif
 
@@ -76,22 +76,24 @@ public:
      */
     QListWidget *listWidget() const;
 
+#if KITEMVIEWS_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * @return the message set with setClickMessage
      * @deprecated since 5.0, use QLineEdit::placeholderText() instead.
      **/
-#ifndef KITEMVIEWS_NO_DEPRECATED
-    KITEMVIEWS_DEPRECATED QString clickMessage() const { return placeholderText(); }
+    KITEMVIEWS_DEPRECATED_VERSION(5, 0, "Use QLineEdit::placeholderText()")
+    QString clickMessage() const { return placeholderText(); }
 #endif
 
+#if KITEMVIEWS_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * This makes the line edit display a grayed-out hinting text as long as
      * the user didn't enter any text. It is often used as indication about
      * the purpose of the line edit.
      * @deprecated since 5.0, use QLineEdit::setPlaceholderText() instead.
      */
-#ifndef KITEMVIEWS_NO_DEPRECATED
-    KITEMVIEWS_DEPRECATED void setClickMessage(const QString &msg) { setPlaceholderText(msg); }
+    KITEMVIEWS_DEPRECATED_VERSION(5, 0, "Use QLineEdit::setPlaceholderText(const QString&)")
+    void setClickMessage(const QString &msg) { setPlaceholderText(msg); }
 #endif
 
 public Q_SLOTS:
@@ -132,7 +134,7 @@ protected:
     /**
      * Re-implemented for internal reasons.  API not affected.
      */
-    bool event(QEvent *event) Q_DECL_OVERRIDE;
+    bool event(QEvent *event) override;
 
 private:
     class KListWidgetSearchLinePrivate;
